@@ -217,10 +217,6 @@ class ParameterSweep(object):
         f_ST_inStrand = cable.f_ST / (cable.f_SC + cable.f_ST)
         I = abs(I)
         J_op = I / A_CableBare
-        print(cable.A_CableInsulated)
-        print(A_CableBare)
-        print(cable.f_SC)
-        print(cable.f_ST)
         Tc = cable.Tc0_NbTi * (1 - B / cable.Bc20_NbTi) ** cable.alpha_NbTi
         Tcs= (1 - I / (cable.c1_Ic_NbTi + cable.c2_Ic_NbTi * B)) * Tc
         Ts = (Tcs + Tc) / 2
@@ -270,6 +266,9 @@ class ParameterSweep(object):
         return newCable
 
     def adjust_vQ(self, ROXIE_File):
+        cable = Cable()
+        cable.A_CableInsulated = (self.ParametersLEDET.Inputs.wBare_inGroup+2*self.ParametersLEDET.Inputs.wIns_inGroup) \
+                               * (self.ParametersLEDET.Inputs.hBare_inGroup+2*self.ParametersLEDET.Inputs.hIns_inGroup)
         B = self.acquireBField(ROXIE_File)
         if max(self.ParametersLEDET.Inputs.nStrands_inGroup) > 1:
             strandCount = 0
@@ -281,17 +280,18 @@ class ParameterSweep(object):
                 if i>TurnSum: GroupCount = GroupCount + 1
                 strandCount = strandCount + self.ParametersLEDET.Inputs.nStrands_inGroup[GroupCount]
             B = Bcopy
+            cable.f_SC = self.ParametersLEDET.Inputs.f_SC_strand_inGroup * \
+                         (self.ParametersLEDET.Inputs.nStrands_inGroup* (np.pi/4)*(self.ParametersLEDET.Inputs.ds_inGroup**2)) / cable.A_CableInsulated
+            cable.f_ST = (1 - self.ParametersLEDET.Inputs.f_SC_strand_inGroup) * \
+                         (self.ParametersLEDET.Inputs.nStrands_inGroup* (np.pi/4)*(self.ParametersLEDET.Inputs.ds_inGroup**2)) / cable.A_CableInsulated
+        else:
+            cable.f_SC = self.ParametersLEDET.Inputs.f_SC_strand_inGroup * \
+                         (self.ParametersLEDET.Inputs.wBare_inGroup * self.ParametersLEDET.Inputs.hBare_inGroup) / cable.A_CableInsulated
+            cable.f_ST = (1 - self.ParametersLEDET.Inputs.f_SC_strand_inGroup) * \
+                         (self.ParametersLEDET.Inputs.wBare_inGroup * self.ParametersLEDET.Inputs.hBare_inGroup) / cable.A_CableInsulated
+
         I = self.ParametersLEDET.Inputs.I00
         T_bath = self.ParametersLEDET.Inputs.T00
-        cable = Cable()
-        cable.A_CableInsulated = (self.ParametersLEDET.Inputs.wBare_inGroup+2*self.ParametersLEDET.Inputs.wIns_inGroup) \
-                               * (self.ParametersLEDET.Inputs.hBare_inGroup+2*self.ParametersLEDET.Inputs.hIns_inGroup)
-        cable.f_SC = self.ParametersLEDET.Inputs.f_SC_strand_inGroup * \
-                        (self.ParametersLEDET.Inputs.wBare_inGroup*self.ParametersLEDET.Inputs.hBare_inGroup)/cable.A_CableInsulated
-        print(cable.f_SC)
-        print((self.ParametersLEDET.Inputs.wBare_inGroup*self.ParametersLEDET.Inputs.hBare_inGroup)/cable.A_CableInsulated)
-        cable.f_ST = (1- self.ParametersLEDET.Inputs.f_SC_strand_inGroup) * \
-                    (self.ParametersLEDET.Inputs.wBare_inGroup*self.ParametersLEDET.Inputs.hBare_inGroup)/cable.A_CableInsulated
         cable.SCtype = self.ParametersLEDET.Inputs.SCtype_inGroup
         cable.STtype = self.ParametersLEDET.Inputs.STtype_inGroup
         cable.Tc0_NbTi = self.ParametersLEDET.Inputs.Tc0_NbTi_ht_inGroup
@@ -306,7 +306,6 @@ class ParameterSweep(object):
 
         vQ = self.quenchPropagationVelocity(I, B, T_bath, cable)
         self.ParametersLEDET.setAttribute(getattr(self.ParametersLEDET, "Inputs"), "vQ_iStartQuench", vQ)
-        print(vQ)
 
     def prepareSimulation(self, MagnetName, folder, cleanFolder = True,  OffsetNumber = 0, ROXIE_File = '', clean = False):
         Adjust_vQ = 0
@@ -356,14 +355,15 @@ class ParameterSweep(object):
 
         #4. Write CSV with all Parameters
         SimNumbers = np.linspace(0,self.SweepMatrix.shape[0]-1,self.SweepMatrix.shape[0])
-        df = pd.Series(SimNumbers,index=SimNumbers)
-        for i in range(self.SweepMatrix.shape[1]):
-            par = pd.Series(self.SweepMatrix[:, i], index=SimNumbers)
-            df = pd.concat([df, par], axis=1)
-        df.columns = np.concatenate((['Simulation'], self.ParametersToSweep))
-        writer = pd.ExcelWriter(folder + "SimulationMatrix.xlsx")
-        df.to_excel(writer)
-        writer.save()
+        if SimNumbers.shape[0]>3:
+            df = pd.Series(SimNumbers,index=SimNumbers)
+            for i in range(self.SweepMatrix.shape[1]):
+                par = pd.Series(self.SweepMatrix[:, i], index=SimNumbers)
+                df = pd.concat([df, par], axis=1)
+            df.columns = np.concatenate((['Simulation'], self.ParametersToSweep))
+            writer = pd.ExcelWriter(folder + "SimulationMatrix.xlsx")
+            df.to_excel(writer)
+            writer.save()
 
 class MinMaxSweep(ParameterSweep):
     def __init__(self, ParametersLEDET, basePoints):
