@@ -660,10 +660,10 @@ class ParametersLEDET:
         '''
         if not SkipConsistencyCheck:
             if self.consistencyCheckLEDET():
-                print("Variables are not consistent! Writing aborted.")
+                print("Variables are not consistent! Writing aborted - ", nameFileLEDET)
                 return
             else:
-                print("Preliminary consistency check was successful!")
+                print("Preliminary consistency check was successful! - ", nameFileLEDET)
 
         workbook = xlsxwriter.Workbook(nameFileLEDET)
 
